@@ -196,15 +196,15 @@ impl<T: Load + Add<Output = T> + Sub<Output = T> + Add<Output = T> + Sub<Output
 
             (0..)
                 .zip(rc.route.tour.all_activities())
-                .filter_map(|(idx, activity)| self.multi_trip.get_reload(activity).map(|_| idx))
-                .filter(|&idx| idx < start || idx > end)
+                .filter_map(|(idx, activity)| self.multi_trip.get_reload(activity).map(|reload| (reload.clone(), idx)))
+                .filter(|(_, idx)| *idx < start || *idx > end)
                 .collect::<Vec<_>>()
                 .into_iter()
                 .rev()
-                .for_each(|idx| {
-                    let job = self.multi_trip.get_reload(rc.route.tour.get(idx).unwrap()).unwrap();
-                    extra_ignored.push(Job::Single(job.clone()));
-                    rc.route_mut().tour.remove_activity_at(idx);
+                .for_each(|(reload, _)| {
+                    let job = Job::Single(reload);
+                    assert!(rc.route_mut().tour.remove(&job));
+                    extra_ignored.push(job);
                 });
 
             if rc.is_stale() {
