@@ -29,17 +29,18 @@ pub struct MultiSelective {
 impl HyperHeuristic for MultiSelective {
     fn search(&mut self, refinement_ctx: &RefinementContext, individuals: Vec<&Individual>) -> Vec<Individual> {
         self.is_slow_search = match (self.is_slow_search, &refinement_ctx.statistics.speed) {
-            (false, RefinementSpeed::Slow) => {
-                refinement_ctx.environment.logger.deref()(
-                    "slow refinement speed, switch to static selective hyper-heuristic",
-                );
+            (false, RefinementSpeed::Slow(ratio)) => {
+                refinement_ctx.environment.logger.deref()(&format!(
+                    "slow refinement speed ({}), switch to static selective hyper-heuristic",
+                    *ratio
+                ));
                 self.inner = Box::new(StaticSelective::new_with_defaults(
                     refinement_ctx.problem.clone(),
                     refinement_ctx.environment.clone(),
                 ));
                 true
             }
-            (true, RefinementSpeed::Slow) => true,
+            (true, RefinementSpeed::Slow(_)) => true,
             _ => false,
         };
 
